@@ -25,7 +25,14 @@ def pip_install(
     # either the virtual environment or the virtualenv package embedded wheel. Version
     # checks are a wasteful network call that adds a lot of wait time when installing a
     # lot of packages.
-    args = ["install", "--disable-pip-version-check", "--prefix", str(environment.path)]
+    args = [
+        "install",
+        "--disable-pip-version-check",
+        "--isolated",
+        "--no-input",
+        "--prefix",
+        str(environment.path),
+    ]
 
     if not is_wheel and not editable:
         args.insert(1, "--use-pep517")
