@@ -43,6 +43,7 @@ def _project_factory(
         name="foobar",
         pyproject_content=pyproject_content,
         poetry_lock_content=poetry_lock_content,
+        source=source,
     )
 
 
@@ -67,6 +68,13 @@ def poetry_with_old_lockfile(
     return _project_factory("old_lock", project_factory, fixture_dir)
 
 
+@pytest.fixture
+def poetry_with_nested_path_deps_old_lockfile(
+    project_factory: ProjectFactory, fixture_dir: FixtureDirGetter
+) -> Poetry:
+    return _project_factory("old_lock_path_dependency", project_factory, fixture_dir)
+
+
 @pytest.fixture
 def poetry_with_incompatible_lockfile(
     project_factory: ProjectFactory, fixture_dir: FixtureDirGetter
@@ -160,12 +168,42 @@ def test_lock_no_update(
 
     assert len(packages) == len(locked_repository.packages)
 
-    assert locker.lock_data["metadata"].get("lock-version") == "1.1"
+    assert locker.lock_data["metadata"].get("lock-version") == "2.0"
 
     for package in packages:
         assert locked_repository.find_packages(package.to_dependency())
 
 
+def test_lock_no_update_path_dependencies(
+    command_tester_factory: CommandTesterFactory,
+    poetry_with_nested_path_deps_old_lockfile: Poetry,
+    repo: TestRepository,
+):
+    """
+    The lock file contains a variant of the directory dependency "quix" that does
+    not depend on "sampleproject". Although the version of "quix" has not been changed,
+    it should be re-solved because there is always only one valid version
+    of a directory dependency at any time.
+    """
+    repo.add_package(get_package("sampleproject", "1.3.1"))
+
+    locker = Locker(
+        lock=poetry_with_nested_path_deps_old_lockfile.pyproject.file.path.parent
+        / "poetry.lock",
+        local_config=poetry_with_nested_path_deps_old_lockfile.locker._local_config,
+    )
+    poetry_with_nested_path_deps_old_lockfile.set_locker(locker)
+
+    tester = command_tester_factory(
+        "lock", poetry=poetry_with_nested_path_deps_old_lockfile
+    )
+    tester.execute("--no-update")
+
+    packages = locker.locked_repository().packages
+
+    assert {p.name for p in packages} == {"quix", "sampleproject"}
+
+
 @pytest.mark.parametrize("is_no_update", [False, True])
 def test_lock_with_incompatible_lockfile(
     command_tester_factory: CommandTesterFactory,
