@@ -87,7 +87,7 @@ def test_show_basic_with_installed_packages(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "pytest": []},
             },
         }
     )
@@ -168,7 +168,7 @@ def _configure_project_with_groups(poetry: Poetry, installed: Repository) -> Non
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "pytest": []},
             },
         }
     )
@@ -293,7 +293,7 @@ def test_show_basic_with_installed_packages_single(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": []},
+                "files": {"cachy": []},
             },
         }
     )
@@ -335,7 +335,7 @@ def test_show_basic_with_installed_packages_single_canonicalized(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"foo-bar": []},
+                "files": {"foo-bar": []},
             },
         }
     )
@@ -390,7 +390,7 @@ def test_show_basic_with_not_installed_packages_non_decorated(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -446,7 +446,7 @@ def test_show_basic_with_not_installed_packages_decorated(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -516,7 +516,7 @@ def test_show_latest_non_decorated(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -586,7 +586,7 @@ def test_show_latest_decorated(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -655,7 +655,7 @@ def test_show_outdated(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -699,7 +699,7 @@ def test_show_outdated_with_only_up_to_date_packages(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": []},
+                "files": {"cachy": []},
             },
         }
     )
@@ -768,7 +768,7 @@ def test_show_outdated_has_prerelease_but_not_allowed(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -843,7 +843,7 @@ def test_show_outdated_has_prerelease_and_allowed(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -912,7 +912,7 @@ def test_show_outdated_formatting(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -1029,7 +1029,7 @@ def test_show_outdated_local_dependencies(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {
+                "files": {
                     "cachy": [],
                     "pendulum": [],
                     "demo": [],
@@ -1136,7 +1136,7 @@ def test_show_outdated_git_dev_dependency(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "demo": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "demo": [], "pytest": []},
             },
         }
     )
@@ -1235,7 +1235,7 @@ def test_show_outdated_no_dev_git_dev_dependency(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "demo": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "demo": [], "pytest": []},
             },
         }
     )
@@ -1296,7 +1296,7 @@ def test_show_hides_incompatible_package(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -1353,7 +1353,7 @@ def test_show_all_shows_incompatible_package(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": []},
+                "files": {"cachy": [], "pendulum": []},
             },
         }
     )
@@ -1368,6 +1368,103 @@ pendulum  2.0.0 Pendulum package
     assert tester.io.fetch_output() == expected
 
 
+def test_show_hides_incompatible_package_with_duplicate(
+    tester: CommandTester,
+    poetry: Poetry,
+    installed: Repository,
+    repo: TestRepository,
+):
+    poetry.package.add_dependency(
+        Factory.create_dependency("cachy", {"version": "0.1.0", "platform": "linux"})
+    )
+    poetry.package.add_dependency(
+        Factory.create_dependency("cachy", {"version": "0.1.1", "platform": "darwin"})
+    )
+
+    poetry.locker.mock_lock_data(
+        {
+            "package": [
+                {
+                    "name": "cachy",
+                    "version": "0.1.0",
+                    "description": "Cachy package",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "files": [],
+                },
+                {
+                    "name": "cachy",
+                    "version": "0.1.1",
+                    "description": "Cachy package",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "files": [],
+                },
+            ],
+            "metadata": {"content-hash": "123456789"},
+        }
+    )
+
+    tester.execute()
+
+    expected = """\
+cachy (!) 0.1.1 Cachy package
+"""
+
+    assert tester.io.fetch_output() == expected
+
+
+def test_show_all_shows_all_duplicates(
+    tester: CommandTester,
+    poetry: Poetry,
+    installed: Repository,
+    repo: TestRepository,
+):
+    poetry.package.add_dependency(
+        Factory.create_dependency("cachy", {"version": "0.1.0", "platform": "linux"})
+    )
+    poetry.package.add_dependency(
+        Factory.create_dependency("cachy", {"version": "0.1.1", "platform": "darwin"})
+    )
+
+    poetry.locker.mock_lock_data(
+        {
+            "package": [
+                {
+                    "name": "cachy",
+                    "version": "0.1.0",
+                    "description": "Cachy package",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "files": [],
+                },
+                {
+                    "name": "cachy",
+                    "version": "0.1.1",
+                    "description": "Cachy package",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "files": [],
+                },
+            ],
+            "metadata": {"content-hash": "123456789"},
+        }
+    )
+
+    tester.execute("--all")
+
+    expected = """\
+cachy     0.1.0 Cachy package
+cachy (!) 0.1.1 Cachy package
+"""
+
+    assert tester.io.fetch_output() == expected
+
+
 def test_show_non_dev_with_basic_installed_packages(
     tester: CommandTester, poetry: Poetry, installed: Repository
 ):
@@ -1429,7 +1526,7 @@ def test_show_non_dev_with_basic_installed_packages(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "pytest": []},
             },
         }
     )
@@ -1505,7 +1602,7 @@ def test_show_with_group_only(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "pytest": []},
             },
         }
     )
@@ -1580,7 +1677,7 @@ def test_show_with_optional_group(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "pytest": []},
+                "files": {"cachy": [], "pendulum": [], "pytest": []},
             },
         }
     )
@@ -1642,7 +1739,7 @@ def test_show_tree(tester: CommandTester, poetry: Poetry, installed: Repository)
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "msgpack-python": []},
+                "files": {"cachy": [], "msgpack-python": []},
             },
         }
     )
@@ -1709,7 +1806,7 @@ def test_show_tree_no_dev(tester: CommandTester, poetry: Poetry, installed: Repo
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "msgpack-python": [], "pytest": []},
+                "files": {"cachy": [], "msgpack-python": [], "pytest": []},
             },
         }
     )
@@ -1768,7 +1865,7 @@ def test_show_tree_why_package(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"a": [], "b": [], "c": []},
+                "files": {"a": [], "b": [], "c": []},
             },
         }
     )
@@ -1825,7 +1922,7 @@ def test_show_tree_why(tester: CommandTester, poetry: Poetry, installed: Reposit
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"a": [], "b": [], "c": []},
+                "files": {"a": [], "b": [], "c": []},
             },
         }
     )
@@ -1894,7 +1991,7 @@ def test_show_required_by_deps(
                 "python-versions": "*",
                 "platform": "*",
                 "content-hash": "123456789",
-                "hashes": {"cachy": [], "pendulum": [], "msgpack-python": []},
+                "files": {"cachy": [], "pendulum": [], "msgpack-python": []},
             },
         }
     )
@@ -1924,3 +2021,122 @@ def test_show_errors_without_lock_file(tester: CommandTester, poetry: Poetry):
     expected = "Error: poetry.lock not found. Run `poetry lock` to create it.\n"
     assert tester.io.fetch_error() == expected
     assert tester.status_code == 1
+
+
+def test_show_dependency_installed_from_git_in_dev(
+    tester: CommandTester,
+    poetry: Poetry,
+    installed: Repository,
+    repo: TestRepository,
+):
+    # Add a regular dependency for a package in main, and a git dependency for the same
+    # package in dev.
+    poetry.package.add_dependency(Factory.create_dependency("demo", "^0.1.1"))
+    poetry.package.add_dependency(
+        Factory.create_dependency(
+            "demo", {"git": "https://github.com/demo/demo.git"}, groups=["dev"]
+        )
+    )
+
+    demo_011 = get_package("demo", "0.1.1")
+    demo_011.description = "Demo package"
+    repo.add_package(demo_011)
+
+    pendulum_200 = get_package("pendulum", "2.0.0")
+    pendulum_200.description = "Pendulum package"
+    repo.add_package(pendulum_200)
+
+    # The git package is the one that gets into the lockfile.
+    poetry.locker.mock_lock_data(
+        {
+            "package": [
+                {
+                    "name": "demo",
+                    "version": "0.1.2",
+                    "description": "Demo package",
+                    "category": "main",
+                    "optional": False,
+                    "python-versions": "*",
+                    "develop": False,
+                    "source": {
+                        "type": "git",
+                        "reference": MOCK_DEFAULT_GIT_REVISION,
+                        "resolved_reference": MOCK_DEFAULT_GIT_REVISION,
+                        "url": "https://github.com/demo/demo.git",
+                    },
+                },
+                {
+                    "name": "pendulum",
+                    "version": "2.0.0",
+                    "description": "Pendulum package",
+                    "category": "main",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "checksum": [],
+                },
+            ],
+            "metadata": {
+                "python-versions": "*",
+                "platform": "*",
+                "content-hash": "123456789",
+                "files": {"demo": [], "pendulum": []},
+            },
+        }
+    )
+
+    # Nothing needs updating, there is no confusion between the git and not-git
+    # packages.
+    tester.execute("--outdated")
+    assert tester.io.fetch_output() == ""
+
+
+def test_url_dependency_is_not_outdated_by_repository_package(
+    tester: CommandTester,
+    poetry: Poetry,
+    installed: Repository,
+    repo: TestRepository,
+):
+    demo_url = "https://python-poetry.org/distributions/demo-0.1.0-py2.py3-none-any.whl"
+    poetry.package.add_dependency(
+        Factory.create_dependency(
+            "demo",
+            {"url": demo_url},
+        )
+    )
+
+    # A newer version of demo is available in the repository.
+    demo_100 = get_package("demo", "1.0.0")
+    repo.add_package(demo_100)
+
+    poetry.locker.mock_lock_data(
+        {
+            "package": [
+                {
+                    "name": "demo",
+                    "version": "0.1.0",
+                    "description": "Demo package",
+                    "category": "main",
+                    "optional": False,
+                    "platform": "*",
+                    "python-versions": "*",
+                    "checksum": [],
+                    "source": {
+                        "type": "url",
+                        "url": demo_url,
+                    },
+                }
+            ],
+            "metadata": {
+                "python-versions": "*",
+                "platform": "*",
+                "content-hash": "123456789",
+                "hashes": {"demo": []},
+            },
+        }
+    )
+
+    # The url dependency on demo is not made outdated by the existence of a newer
+    # version in the repository.
+    tester.execute("--outdated")
+    assert tester.io.fetch_output() == ""
