@@ -3,6 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING
 
 from cleo.io.null_io import NullIO
+from packaging.utils import canonicalize_name
 from poetry.core.packages.package import Package
 
 from poetry.factory import Factory
@@ -15,12 +16,12 @@ from tests.mixology.version_solver.conftest import Provider
 if TYPE_CHECKING:
     from poetry.core.packages.project_package import ProjectPackage
 
-    from poetry.repositories import Pool
     from poetry.repositories import Repository
+    from poetry.repositories import RepositoryPool
 
 
 def test_with_compatible_locked_dependencies(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "*"))
 
@@ -31,16 +32,18 @@ def test_with_compatible_locked_dependencies(
     add_to_repo(repo, "bar", "1.0.1")
     add_to_repo(repo, "bar", "1.0.2")
 
+    locked = [get_package("foo", "1.0.1"), get_package("bar", "1.0.1")]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.1", "bar": "1.0.1"},
-        locked={"foo": get_package("foo", "1.0.1"), "bar": get_package("bar", "1.0.1")},
     )
 
 
 def test_with_incompatible_locked_dependencies(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", ">1.0.1"))
 
@@ -51,16 +54,18 @@ def test_with_incompatible_locked_dependencies(
     add_to_repo(repo, "bar", "1.0.1")
     add_to_repo(repo, "bar", "1.0.2")
 
+    locked = [get_package("foo", "1.0.1"), get_package("bar", "1.0.1")]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.2", "bar": "1.0.2"},
-        locked={"foo": get_package("foo", "1.0.1"), "bar": get_package("bar", "1.0.1")},
     )
 
 
 def test_with_unrelated_locked_dependencies(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "*"))
 
@@ -72,16 +77,18 @@ def test_with_unrelated_locked_dependencies(
     add_to_repo(repo, "bar", "1.0.2")
     add_to_repo(repo, "baz", "1.0.0")
 
+    locked = [get_package("baz", "1.0.1")]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.2", "bar": "1.0.2"},
-        locked={"baz": get_package("baz", "1.0.1")},
     )
 
 
 def test_unlocks_dependencies_if_necessary_to_ensure_that_a_new_dependency_is_satisfied(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "*"))
     root.add_dependency(Factory.create_dependency("newdep", "2.0.0"))
@@ -96,6 +103,14 @@ def test_unlocks_dependencies_if_necessary_to_ensure_that_a_new_dependency_is_sa
     add_to_repo(repo, "qux", "2.0.0")
     add_to_repo(repo, "newdep", "2.0.0", deps={"baz": ">=1.5.0"})
 
+    locked = [
+        get_package("foo", "2.0.0"),
+        get_package("bar", "1.0.0"),
+        get_package("baz", "1.0.0"),
+        get_package("qux", "1.0.0"),
+    ]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
@@ -106,17 +121,11 @@ def test_unlocks_dependencies_if_necessary_to_ensure_that_a_new_dependency_is_sa
             "qux": "1.0.0",
             "newdep": "2.0.0",
         },
-        locked={
-            "foo": get_package("foo", "2.0.0"),
-            "bar": get_package("bar", "1.0.0"),
-            "baz": get_package("baz", "1.0.0"),
-            "qux": get_package("qux", "1.0.0"),
-        },
     )
 
 
 def test_with_compatible_locked_dependencies_use_latest(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "*"))
     root.add_dependency(Factory.create_dependency("baz", "*"))
@@ -130,21 +139,23 @@ def test_with_compatible_locked_dependencies_use_latest(
     add_to_repo(repo, "baz", "1.0.0")
     add_to_repo(repo, "baz", "1.0.1")
 
+    locked = [
+        get_package("foo", "1.0.1"),
+        get_package("bar", "1.0.1"),
+        get_package("baz", "1.0.0"),
+    ]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.2", "bar": "1.0.2", "baz": "1.0.0"},
-        locked={
-            "foo": get_package("foo", "1.0.1"),
-            "bar": get_package("bar", "1.0.1"),
-            "baz": get_package("baz", "1.0.0"),
-        },
-        use_latest=["foo"],
+        use_latest=[canonicalize_name("foo")],
     )
 
 
 def test_with_compatible_locked_dependencies_with_extras(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "^1.0"))
 
@@ -163,20 +174,22 @@ def test_with_compatible_locked_dependencies_with_extras(
     add_to_repo(repo, "baz", "1.0.0")
     add_to_repo(repo, "baz", "1.0.1")
 
+    locked = [
+        get_package("foo", "1.0.0"),
+        get_package("bar", "1.0.0"),
+        get_package("baz", "1.0.0"),
+    ]
+    provider = Provider(root, pool, NullIO(), locked=locked)
+
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.0", "bar": "1.0.0", "baz": "1.0.0"},
-        locked={
-            "foo": get_package("foo", "1.0.0"),
-            "bar": get_package("bar", "1.0.0"),
-            "baz": get_package("baz", "1.0.0"),
-        },
     )
 
 
 def test_with_yanked_package_in_lock(
-    root: ProjectPackage, provider: Provider, repo: Repository
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "*"))
 
@@ -186,16 +199,17 @@ def test_with_yanked_package_in_lock(
     # yanked version is kept in lock file
     locked_foo = get_package("foo", "2")
     assert not locked_foo.yanked
+    provider = Provider(root, pool, NullIO(), locked=[locked_foo])
     result = check_solver_result(
         root,
         provider,
         result={"foo": "2"},
-        locked={"foo": locked_foo},
     )
     foo = result.packages[0]
     assert foo.yanked
 
     # without considering the lock file, the other version is chosen
+    provider = Provider(root, pool, NullIO())
     check_solver_result(
         root,
         provider,
@@ -204,7 +218,7 @@ def test_with_yanked_package_in_lock(
 
 
 def test_no_update_is_respected_for_legacy_repository(
-    root: ProjectPackage, repo: Repository, pool: Pool
+    root: ProjectPackage, repo: Repository, pool: RepositoryPool
 ):
     root.add_dependency(Factory.create_dependency("foo", "^1.0"))
 
@@ -217,10 +231,9 @@ def test_no_update_is_respected_for_legacy_repository(
     repo.add_package(foo_100)
     repo.add_package(foo_101)
 
-    provider = Provider(root, pool, NullIO())
+    provider = Provider(root, pool, NullIO(), locked=[foo_100])
     check_solver_result(
         root,
         provider,
         result={"foo": "1.0.0"},
-        locked={"foo": foo_100},
     )
