@@ -11,7 +11,6 @@ from typing import Any
 import pytest
 import tomlkit
 
-from cleo.io.null_io import NullIO
 from poetry.core.constraints.version import Version
 from poetry.core.toml.file import TOMLFile
 
@@ -22,6 +21,7 @@ from poetry.utils.env import GET_BASE_PREFIX
 from poetry.utils.env import EnvCommandError
 from poetry.utils.env import EnvManager
 from poetry.utils.env import GenericEnv
+from poetry.utils.env import IncorrectEnvError
 from poetry.utils.env import InvalidCurrentPythonVersionError
 from poetry.utils.env import MockEnv
 from poetry.utils.env import NoCompatiblePythonVersionFound
@@ -208,6 +208,7 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
@@ -224,8 +225,7 @@ def test_activate_activates_non_existing_virtualenv_no_envs_file(
     )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
-    env = manager.activate("python3.7", NullIO())
-    venv_name = EnvManager.generate_env_name("simple-project", str(poetry.file.parent))
+    env = manager.activate("python3.7")
 
     m.assert_called_with(
         Path(tmp_dir) / f"{venv_name}-py3.7",
@@ -255,12 +255,11 @@ def test_activate_activates_existing_virtualenv_no_envs_file(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
-
     os.mkdir(os.path.join(tmp_dir, f"{venv_name}-py3.7"))
 
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
@@ -275,7 +274,7 @@ def test_activate_activates_existing_virtualenv_no_envs_file(
     )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
-    env = manager.activate("python3.7", NullIO())
+    env = manager.activate("python3.7")
 
     m.assert_not_called()
 
@@ -295,12 +294,11 @@ def test_activate_activates_same_virtualenv_with_envs_file(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
-
     envs_file = TOMLFile(Path(tmp_dir) / "envs.toml")
     doc = tomlkit.document()
     doc[venv_name] = {"minor": "3.7", "patch": "3.7.1"}
@@ -320,7 +318,7 @@ def test_activate_activates_same_virtualenv_with_envs_file(
     )
     m = mocker.patch("poetry.utils.env.EnvManager.create_venv")
 
-    env = manager.activate("python3.7", NullIO())
+    env = manager.activate("python3.7")
 
     m.assert_not_called()
 
@@ -339,11 +337,11 @@ def test_activate_activates_different_virtualenv_with_envs_file(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     envs_file = TOMLFile(Path(tmp_dir) / "envs.toml")
     doc = tomlkit.document()
     doc[venv_name] = {"minor": "3.7", "patch": "3.7.1"}
@@ -363,7 +361,7 @@ def test_activate_activates_different_virtualenv_with_envs_file(
     )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv", side_effect=build_venv)
 
-    env = manager.activate("python3.6", NullIO())
+    env = manager.activate("python3.6")
 
     m.assert_called_with(
         Path(tmp_dir) / f"{venv_name}-py3.6",
@@ -392,11 +390,11 @@ def test_activate_activates_recreates_for_different_patch(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     envs_file = TOMLFile(Path(tmp_dir) / "envs.toml")
     doc = tomlkit.document()
     doc[venv_name] = {"minor": "3.7", "patch": "3.7.0"}
@@ -427,7 +425,7 @@ def test_activate_activates_recreates_for_different_patch(
         "poetry.utils.env.EnvManager.remove_venv", side_effect=EnvManager.remove_venv
     )
 
-    env = manager.activate("python3.7", NullIO())
+    env = manager.activate("python3.7")
 
     build_venv_m.assert_called_with(
         Path(tmp_dir) / f"{venv_name}-py3.7",
@@ -458,11 +456,11 @@ def test_activate_does_not_recreate_when_switching_minor(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     envs_file = TOMLFile(Path(tmp_dir) / "envs.toml")
     doc = tomlkit.document()
     doc[venv_name] = {"minor": "3.7", "patch": "3.7.0"}
@@ -488,7 +486,7 @@ def test_activate_does_not_recreate_when_switching_minor(
         "poetry.utils.env.EnvManager.remove_venv", side_effect=EnvManager.remove_venv
     )
 
-    env = manager.activate("python3.6", NullIO())
+    env = manager.activate("python3.6")
 
     build_venv_m.assert_not_called()
     remove_venv_m.assert_not_called()
@@ -509,12 +507,11 @@ def test_deactivate_non_activated_but_existing(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
-
     python = ".".join(str(c) for c in sys.version_info[:2])
     (Path(tmp_dir) / f"{venv_name}-py{python}").mkdir()
 
@@ -525,7 +522,7 @@ def test_deactivate_non_activated_but_existing(
         side_effect=check_output_wrapper(),
     )
 
-    manager.deactivate(NullIO())
+    manager.deactivate()
     env = manager.get()
 
     assert env.path == Path(tmp_dir) / f"{venv_name}-py{python}"
@@ -538,11 +535,11 @@ def test_deactivate_activated(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     version = Version.from_parts(*sys.version_info[:3])
     other_version = Version.parse("3.4") if version.major == 2 else version.next_minor()
     (Path(tmp_dir) / f"{venv_name}-py{version.major}.{version.minor}").mkdir()
@@ -565,7 +562,7 @@ def test_deactivate_activated(
         side_effect=check_output_wrapper(),
     )
 
-    manager.deactivate(NullIO())
+    manager.deactivate()
     env = manager.get()
 
     assert env.path == Path(tmp_dir) / f"{venv_name}-py{version.major}.{version.minor}"
@@ -581,11 +578,10 @@ def test_get_prefers_explicitly_activated_virtualenvs_over_env_var(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     os.environ["VIRTUAL_ENV"] = "/environment/prefix"
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
-
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
     (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
 
@@ -609,10 +605,15 @@ def test_get_prefers_explicitly_activated_virtualenvs_over_env_var(
     assert env.base == Path("/prefix")
 
 
-def test_list(tmp_dir: str, manager: EnvManager, poetry: Poetry, config: Config):
+def test_list(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+    venv_name: str,
+):
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
     (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
 
@@ -629,10 +630,10 @@ def test_remove_by_python_version(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
     (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
 
@@ -654,10 +655,10 @@ def test_remove_by_name(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
     (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
 
@@ -673,7 +674,59 @@ def test_remove_by_name(
     assert not expected_venv_path.exists()
 
 
-def test_remove_also_deactivates(
+def test_remove_by_string_with_python_and_version(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+    mocker: MockerFixture,
+    venv_name: str,
+):
+    config.merge({"virtualenvs": {"path": str(tmp_dir)}})
+
+    (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
+    (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
+
+    mocker.patch(
+        "subprocess.check_output",
+        side_effect=check_output_wrapper(Version.parse("3.6.6")),
+    )
+
+    venv = manager.remove("python3.6")
+
+    expected_venv_path = Path(tmp_dir) / f"{venv_name}-py3.6"
+    assert venv.path == expected_venv_path
+    assert not expected_venv_path.exists()
+
+
+def test_remove_by_full_path_to_python(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+    mocker: MockerFixture,
+    venv_name: str,
+):
+    config.merge({"virtualenvs": {"path": str(tmp_dir)}})
+
+    (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
+    (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
+
+    mocker.patch(
+        "subprocess.check_output",
+        side_effect=check_output_wrapper(Version.parse("3.6.6")),
+    )
+
+    expected_venv_path = Path(tmp_dir) / f"{venv_name}-py3.6"
+    python_path = expected_venv_path / "bin" / "python"
+
+    venv = manager.remove(str(python_path))
+
+    assert venv.path == expected_venv_path
+    assert not expected_venv_path.exists()
+
+
+def test_raises_if_acting_on_different_project_by_full_path(
     tmp_dir: str,
     manager: EnvManager,
     poetry: Poetry,
@@ -682,7 +735,88 @@ def test_remove_also_deactivates(
 ):
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
+    different_venv_name = "different-project"
+    different_venv_path = Path(tmp_dir) / f"{different_venv_name}-py3.6"
+    different_venv_bin_path = different_venv_path / "bin"
+    different_venv_bin_path.mkdir(parents=True)
+
+    python_path = different_venv_bin_path / "python"
+    python_path.touch(exist_ok=True)
+
+    # Patch initial call where python env path is extracted
+    mocker.patch(
+        "subprocess.check_output",
+        side_effect=lambda *args, **kwargs: str(different_venv_path),
+    )
+
+    with pytest.raises(IncorrectEnvError):
+        manager.remove(str(python_path))
+
+
+def test_raises_if_acting_on_different_project_by_name(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+):
+    config.merge({"virtualenvs": {"path": str(tmp_dir)}})
+
+    different_venv_name = (
+        EnvManager.generate_env_name(
+            "different-project",
+            str(poetry.file.parent),
+        )
+        + "-py3.6"
+    )
+    different_venv_path = Path(tmp_dir) / different_venv_name
+    different_venv_bin_path = different_venv_path / "bin"
+    different_venv_bin_path.mkdir(parents=True)
+
+    python_path = different_venv_bin_path / "python"
+    python_path.touch(exist_ok=True)
+
+    with pytest.raises(IncorrectEnvError):
+        manager.remove(different_venv_name)
+
+
+def test_raises_when_passing_old_env_after_dir_rename(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+    venv_name: str,
+):
+    # Make sure that poetry raises when trying to remove old venv after you've renamed
+    # root directory of the project, which will create another venv with new name.
+    # This is not ideal as you still "can't" remove it by name, but it at least doesn't
+    # cause any unwanted side effects
+    config.merge({"virtualenvs": {"path": str(tmp_dir)}})
+
+    previous_venv_name = EnvManager.generate_env_name(
+        poetry.package.name,
+        "previous_dir_name",
+    )
+    venv_path = Path(tmp_dir) / f"{venv_name}-py3.6"
+    venv_path.mkdir()
+
+    previous_venv_name = f"{previous_venv_name}-py3.6"
+    previous_venv_path = Path(tmp_dir) / previous_venv_name
+    previous_venv_path.mkdir()
+
+    with pytest.raises(IncorrectEnvError):
+        manager.remove(previous_venv_name)
+
+
+def test_remove_also_deactivates(
+    tmp_dir: str,
+    manager: EnvManager,
+    poetry: Poetry,
+    config: Config,
+    mocker: MockerFixture,
+    venv_name: str,
+):
+    config.merge({"virtualenvs": {"path": str(tmp_dir)}})
+
     (Path(tmp_dir) / f"{venv_name}-py3.7").mkdir()
     (Path(tmp_dir) / f"{venv_name}-py3.6").mkdir()
 
@@ -712,12 +846,12 @@ def test_remove_keeps_dir_if_not_deleteable(
     poetry: Poetry,
     config: Config,
     mocker: MockerFixture,
+    venv_name: str,
 ):
     # Ensure we empty rather than delete folder if its is an active mount point.
     # See https://github.com/python-poetry/poetry/pull/2064
     config.merge({"virtualenvs": {"path": str(tmp_dir)}})
 
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
     venv_path = Path(tmp_dir) / f"{venv_name}-py3.6"
     venv_path.mkdir()
 
@@ -848,12 +982,12 @@ def test_create_venv_tries_to_find_a_compatible_python_executable_using_generic_
     config: Config,
     mocker: MockerFixture,
     config_virtualenvs_path: Path,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
     poetry.package.python_versions = "^3.6"
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
 
     mocker.patch("sys.version_info", (2, 7, 16))
     mocker.patch(
@@ -864,7 +998,7 @@ def test_create_venv_tries_to_find_a_compatible_python_executable_using_generic_
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     m.assert_called_with(
         config_virtualenvs_path / f"{venv_name}-py3.7",
@@ -885,12 +1019,12 @@ def test_create_venv_tries_to_find_a_compatible_python_executable_using_specific
     config: Config,
     mocker: MockerFixture,
     config_virtualenvs_path: Path,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
     poetry.package.python_versions = "^3.6"
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
 
     mocker.patch("sys.version_info", (2, 7, 16))
     mocker.patch("subprocess.check_output", side_effect=["3.5.3", "3.9.0"])
@@ -898,7 +1032,7 @@ def test_create_venv_tries_to_find_a_compatible_python_executable_using_specific
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     m.assert_called_with(
         config_virtualenvs_path / f"{venv_name}-py3.9",
@@ -927,7 +1061,7 @@ def test_create_venv_fails_if_no_compatible_python_version_could_be_found(
     )
 
     with pytest.raises(NoCompatiblePythonVersionFound) as e:
-        manager.create_venv(NullIO())
+        manager.create_venv()
 
     expected_message = (
         "Poetry was unable to find a compatible version. "
@@ -953,7 +1087,7 @@ def test_create_venv_does_not_try_to_find_compatible_versions_with_executable(
     )
 
     with pytest.raises(NoCompatiblePythonVersionFound) as e:
-        manager.create_venv(NullIO(), executable="3.8")
+        manager.create_venv(executable="3.8")
 
     expected_message = (
         "The specified Python version (3.8.0) is not supported by the project (^4.8).\n"
@@ -971,6 +1105,7 @@ def test_create_venv_uses_patch_version_to_detect_compatibility(
     config: Config,
     mocker: MockerFixture,
     config_virtualenvs_path: Path,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
@@ -979,7 +1114,6 @@ def test_create_venv_uses_patch_version_to_detect_compatibility(
     poetry.package.python_versions = "^" + ".".join(
         str(c) for c in sys.version_info[:3]
     )
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
 
     mocker.patch("sys.version_info", (version.major, version.minor, version.patch + 1))
     check_output = mocker.patch(
@@ -990,7 +1124,7 @@ def test_create_venv_uses_patch_version_to_detect_compatibility(
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     assert not check_output.called
     m.assert_called_with(
@@ -1012,13 +1146,13 @@ def test_create_venv_uses_patch_version_to_detect_compatibility_with_executable(
     config: Config,
     mocker: MockerFixture,
     config_virtualenvs_path: Path,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
     version = Version.from_parts(*sys.version_info[:3])
     poetry.package.python_versions = f"~{version.major}.{version.minor-1}.0"
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
 
     check_output = mocker.patch(
         "subprocess.check_output",
@@ -1030,9 +1164,7 @@ def test_create_venv_uses_patch_version_to_detect_compatibility_with_executable(
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(
-        NullIO(), executable=f"python{version.major}.{version.minor - 1}"
-    )
+    manager.create_venv(executable=f"python{version.major}.{version.minor - 1}")
 
     assert check_output.called
     m.assert_called_with(
@@ -1054,7 +1186,7 @@ def test_create_venv_fails_if_current_python_version_is_not_supported(
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     current_version = Version.parse(".".join(str(c) for c in sys.version_info[:3]))
     next_version = ".".join(
@@ -1064,7 +1196,7 @@ def test_create_venv_fails_if_current_python_version_is_not_supported(
     poetry.package.python_versions = package_version
 
     with pytest.raises(InvalidCurrentPythonVersionError) as e:
-        manager.create_venv(NullIO())
+        manager.create_venv()
 
     expected_message = (
         f"Current Python version ({current_version}) is not allowed by the project"
@@ -1104,7 +1236,7 @@ def test_activate_with_in_project_setting_does_not_fail_if_no_venvs_dir(
     )
     m = mocker.patch("poetry.utils.env.EnvManager.build_venv")
 
-    manager.activate("python3.7", NullIO())
+    manager.activate("python3.7")
 
     m.assert_called_with(
         poetry.file.parent / ".venv",
@@ -1320,12 +1452,12 @@ def test_create_venv_accepts_fallback_version_w_nonzero_patchlevel(
     config: Config,
     mocker: MockerFixture,
     config_virtualenvs_path: Path,
+    venv_name: str,
 ):
     if "VIRTUAL_ENV" in os.environ:
         del os.environ["VIRTUAL_ENV"]
 
     poetry.package.python_versions = "~3.5.1"
-    venv_name = manager.generate_env_name("simple-project", str(poetry.file.parent))
 
     check_output = mocker.patch(
         "subprocess.check_output",
@@ -1337,7 +1469,7 @@ def test_create_venv_accepts_fallback_version_w_nonzero_patchlevel(
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     assert check_output.called
     m.assert_called_with(
@@ -1353,9 +1485,12 @@ def test_create_venv_accepts_fallback_version_w_nonzero_patchlevel(
     )
 
 
-def test_generate_env_name_ignores_case_for_case_insensitive_fs(tmp_dir: str):
-    venv_name1 = EnvManager.generate_env_name("simple-project", "MyDiR")
-    venv_name2 = EnvManager.generate_env_name("simple-project", "mYdIr")
+def test_generate_env_name_ignores_case_for_case_insensitive_fs(
+    poetry: Poetry,
+    tmp_dir: str,
+):
+    venv_name1 = EnvManager.generate_env_name(poetry.package.name, "MyDiR")
+    venv_name2 = EnvManager.generate_env_name(poetry.package.name, "mYdIr")
     if sys.platform == "win32":
         assert venv_name1 == venv_name2
     else:
@@ -1397,6 +1532,7 @@ def test_build_environment_called_build_script_specified(
                 "install",
                 "--disable-pip-version-check",
                 "--ignore-installed",
+                "--no-input",
                 *extended_without_setup_poetry.pyproject.build_system.requires,
             ]
         ]
@@ -1442,7 +1578,7 @@ def test_create_venv_project_name_empty_sets_correct_prompt(
         "poetry.utils.env.EnvManager.build_venv", side_effect=lambda *args, **kwargs: ""
     )
 
-    manager.create_venv(NullIO())
+    manager.create_venv()
 
     m.assert_called_with(
         config_virtualenvs_path / f"{venv_name}-py3.7",
